From e7460ef3cb124fb7149614b348f754e2b4f2f658 Mon Sep 17 00:00:00 2001
From: Britney Fransen <brfransen@gmail.com>
Date: Tue, 10 Feb 2015 18:51:11 +0000
Subject: web-on-linhes: update stream list

change chrome command for kiosk changes

add support for mv_ir.py wol-lircrc location
---
 abs/extra/web-on-linhes/PKGBUILD              |  8 ++--
 abs/extra/web-on-linhes/web-on-linhes.sh      | 14 +++---
 abs/extra/web-on-linhes/web-on-linhes_is.conf | 64 +++++++--------------------
 3 files changed, 28 insertions(+), 58 deletions(-)

diff --git a/abs/extra/web-on-linhes/PKGBUILD b/abs/extra/web-on-linhes/PKGBUILD
index 64afe1e..0d916bf 100644
--- a/abs/extra/web-on-linhes/PKGBUILD
+++ b/abs/extra/web-on-linhes/PKGBUILD
@@ -2,8 +2,8 @@
 # Maintainer: Cecil Watson<knoppmyth@gmail.com>
 
 pkgname=web-on-linhes
-pkgver=1.00.0
-pkgrel=7
+pkgver=1.01.0
+pkgrel=1
 pkgdesc="Added multiple websites with 10' UIs to Play Online Streams."
 arch=('i686' 'x86_64')
 license=('GPL2')
@@ -19,5 +19,5 @@ package() {
   	#add in file for gen_is.xml
   	install -D -m0744 ${srcdir}/web-on-linhes_is.conf ${pkgdir}/etc/gen_is_xml.d/web-on-linhes_is.conf
 }
-md5sums=('bf15498dcbdc3852aca9cccb0aacd913'
-         'c342f02c88728b227f02018658d6ee53')
+md5sums=('b04992d48e45411bdeed23e6aa9f95f7'
+         '926982798d1c1a8bfd45da8eef8a56f3')
diff --git a/abs/extra/web-on-linhes/web-on-linhes_is.conf b/abs/extra/web-on-linhes/web-on-linhes_is.conf
index 0e9ff60..ec895be 100755
--- a/abs/extra/web-on-linhes/web-on-linhes_is.conf
+++ b/abs/extra/web-on-linhes/web-on-linhes_is.conf
@@ -1,48 +1,16 @@
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>Google Spotlight</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.google.com/tv/spotlight-gallery.html</action>
-     </button>
-  <!--#WebOnTV-->
-
-  <!--#WebOnTV-->
-     <button>
-       <type>STREAM</type>
-       <text>Blip tv</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://blip.tv/?skin=googletv</action>
-     </button>
-  <!--#WebOnTV-->
-
-  <!--#WebOnTV-->
-     <button>
-       <type>STREAM</type>
-       <text>Chow</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.chow.com/tv</action>
-     </button>
-  <!--#WebOnTV-->
-
-  <!--#WebOnTV-->
-     <button>
-       <type>STREAM</type>
-       <text>Clicker TV</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://tv.clicker.com/</action>
-     </button>
-  <!--#WebOnTV-->
-
-  <!--#WebOnTV-->
-     <button>
-       <type>STREAM</type>
-       <text>Crackle</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.crackle.com/gtv/</action>
+       <text>NetFlix</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://netflix.com/WiHome</action>
      </button>
   <!--#WebOnTV-->
 
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>Dailymotion</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://iptv-app.dailymotion.com/dm-front-googletv/dojoroot/app/pages/webkit/index.jsp?&amp;qlang=us</action>
+       <text>Google Spotlight</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.google.com/tv/spotlight-gallery.html</action>
      </button>
   <!--#WebOnTV-->
 
@@ -50,39 +18,39 @@
      <button>
        <type>STREAM</type>
        <text>Flixster</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.flixster.com/tv/google</action>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://admin.flixster.com/googletv</action>
      </button>
   <!--#WebOnTV-->
 
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>Fraboom</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://fraboom.com/google/tv/ </action>
+       <text>The Onion</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.theonion.com/video/googletv/</action>
      </button>
   <!--#WebOnTV-->
 
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>KQED</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://kqed.tv/</action>
+       <text>The New York Times</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.nytimes.com/gtv/</action>
      </button>
   <!--#WebOnTV-->
 
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>Revision 3</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://tv.revision3.com</action>
+       <text>NPR</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.npr.org/googletv/</action>
      </button>
   <!--#WebOnTV-->
 
   <!--#WebOnTV-->
      <button>
        <type>STREAM</type>
-       <text>The Onion</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.theonion.com/video/googletv/</action>
+       <text>PBS Kids</text>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://pbskids.org/video/</action>
      </button>
   <!--#WebOnTV-->
 
@@ -90,7 +58,7 @@
      <button>
        <type>STREAM</type>
        <text>TuneIn </text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://tv.tunein.com/</action>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://tv.tunein.com/</action>
      </button>
   <!--#WebOnTV-->
 
@@ -98,7 +66,7 @@
      <button>
        <type>STREAM</type>
        <text>Vimeo</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.vimeo.com/couchmode</action>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.vimeo.com/couchmode</action>
      </button>
   <!--#WebOnTV-->
 
@@ -106,6 +74,6 @@
      <button>
        <type>STREAM</type>
        <text>YouTube</text>
-       <action>EXEC /usr/LH/bin/web-on-linhes.sh --no-first-run --kiosk http://www.youtube.com/leanback</action>
+       <action>EXEC /usr/LH/bin/web-on-linhes.sh http://www.youtube.com/tv</action>
      </button>
   <!--#WebOnTV-->
diff --git a/abs/extra/web-on-linhes/web-on-linhes.sh b/abs/extra/web-on-linhes/web-on-linhes.sh
index 11098ba..7d9b99b 100644
--- a/abs/extra/web-on-linhes/web-on-linhes.sh
+++ b/abs/extra/web-on-linhes/web-on-linhes.sh
@@ -1,11 +1,13 @@
 #!/bin/sh
 #Script to facilitate Web On LinHES
 #Runs irxevent
-irxevent /home/mythtv/.mythtv/wol-lircrc &
-#Stops xscreensaver from running. 
+irxevent /etc/wol-lircrc &
+irxPID=$!
+#Stops xscreensaver from running.
 stop_xss.sh &
-#Launches chromium in full screen
-chromium $@ 
+xssPID=$!
+#Launches chrome in full screen
+google-chrome --no-first-run --user-data-dir=/home/mythtv/.cache/google-chrome/Default/ --kiosk $@
 #Once done, stops irxevent and stop_xss.sh
-killall irxevent
-killall stop_xss.sh
+kill $irxPID
+kill $xssPID
-- 
cgit v0.12